==> jaguar_session-0.8.1.tar.gz: example/jwt_auth_header/server/server.dart <==
library example.basic_auth.server;

import 'dart:async';

import 'package:jaguar/jaguar.dart';
import 'package:jaguar_auth/jaguar_auth.dart';
import 'package:jaguar_session/jaguar_session.dart';
import 'package:jaguar_jwt/jaguar_jwt.dart';

import '../../common/models/book/book.dart';
import '../../common/user.dart';
import '../../common/books.dart';

//This is the session manager that is passed to SessionInterceptor
JwtAuthHeaderSession sessionManager() =>
    new JwtAuthHeaderSession(authenticationCtx, authorizationCtx);

///JWT Authentication context used by [JwtAuthHeaderSessionManager]
final authenticationCtx = new AuthenticationConf.SymmetricKey(
    'sdgdflgujsdgndsflkgjsdlnwertwert78676', 'jaguar',
    audience: ['book']);

///JWT Authorization context used by [JwtAuthHeaderSessionManager]
final authorizationCtx = new AuthorizationConf.SymmetricKey(
    'sdgdflgujsdgndsflkgjsdlnwertwert78676', 'jaguar',
    audience: ['book']);

class BaseApi {
  BasicAuth basicAuth(Context ctx) => new BasicAuth(kModelManager,
      authorizationIdKey: 'sub', sessionManager: sessionManager());

  Authorizer authorizer(Context ctx) => new Authorizer(kModelManager,
      authorizationIdKey: 'sub', sessionManager: sessionManager());
}

/// This route group contains login and logout authentication routes
@Api()
class AuthRoutes extends BaseApi {
  @Post(path: '/login')
  // Wrap [BasicAuth] interceptor to authenticate
  @WrapOne(#basicAuth)
  void login(Context ctx) {}

  @Post(path: '/logout')
  Future<Null> logout(Context ctx) async {
    final SessionManager sessionManager = ctx.getInput(Authorizer);
    await sessionManager.deleteSession();
  }
}

/// Collection of routes that need authorization
@Api(path: '/book')
@WrapOne(#authorizer)
class StudentRoutes extends BaseApi {
  @Get(path: '/all')
  Response<String> getAllBooks(Context ctx) {
    // Authorized user can be obtained from Authorizer as Input
    User user = ctx.getInput(Authorizer);
    print(user.username);
    List<Map> ret = books.values.map((Book book) => book.toMap()).toList();
    return Response.json(ret);
  }

  @Get(path: '/:id')
  Response<String> getBook(Context ctx) {
    final String id = ctx.pathParams['id'];
    final Book book = books[id];
    return Response.json(book.toMap());
  }
}

@Api(path: '/api')
class LibraryApi {
  @IncludeApi()
  final AuthRoutes auth = new AuthRoutes();

  @IncludeApi()
  final StudentRoutes student = new StudentRoutes();
}

server() async {
  final jaguar = new Jaguar();
  jaguar.addApiReflected(new LibraryApi());

  await jaguar.serve();
}

==> jaguar_session-0.9.1.tar.gz: example/jwt_auth_header/server/server.dart <==
library example.basic_auth.server;

import 'dart:async';

import 'package:jaguar/jaguar.dart';
import 'package:jaguar_auth/jaguar_auth.dart';
import 'package:jaguar_session/jaguar_session.dart';
import 'package:jaguar_serializer/serializer.dart';
import 'package:jaguar_json/jaguar_json.dart';

import '../../common/models/models.dart';
import '../../common/books.dart';

/// Creates session manager
JwtHeaderSession sessionManager() => new JwtHeaderSession(jwtConfig);

/// JWT Authentication context used by [JwtHeaderSession]
const jwtConfig = const JwtConfig('sdgdflgujsdgndsflkgjsdlnwertwert78676',
    issuer: 'jaguar.com');

class BaseApi extends Object with JsonRoutes {
  JsonRepo get repo => jsonRepo;

  BasicAuth basicAuth(Context ctx) => new BasicAuth(kModelManager,
      authorizationIdKey: 'sub', sessionManager: sessionManager());

  Authorizer authorizer(Context ctx) => new Authorizer(kModelManager,
      authorizationIdKey: 'sub', sessionManager: sessionManager());
}

/// This route group contains login and logout authentication routes
@Api()
class AuthRoutes extends BaseApi {
  @Post(path: '/login')
  // Wrap [BasicAuth] interceptor to authenticate
  @WrapOne(#basicAuth)
  Response<String> login(Context ctx) {
    final User user = ctx.getInput<User>(BasicAuth);
    return toJson(user);
  }

  @Post(path: '/logout')
  Future<Null> logout(Context ctx) async {
    final SessionManager sessionManager = ctx.getInput(Authorizer);
    await sessionManager.deleteSession();
  }
}

/// Collection of routes that need authorization
@Api(path: '/book')
@WrapOne(#authorizer)
class StudentRoutes extends BaseApi {
  @Get()
  Response<String> getAllBooks(Context ctx) {
    // Authorized user can be obtained from Authorizer as Input
    User user = ctx.getInput(Authorizer);
    print(user.username);
    return toJson(books.values);
  }

  @Get(path: '/:id')
  Response<String> getBook(Context ctx) {
    String id = ctx.pathParams.get('id');
    Book book = books[id];
    return toJson(book);
  }
}

@Api(path: '/api')
class LibraryApi {
  @IncludeApi()
  final AuthRoutes auth = new AuthRoutes();

  @IncludeApi()
  final StudentRoutes student = new StudentRoutes();
}

server() async {
  final jaguar = new Jaguar();
  jaguar.addApiReflected(new LibraryApi());

  await jaguar.serve();
}
